@@ -1,5 +1,6 @@
+/* -*-mode: C; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*- */
 
-/*	$Id: tixDiStyle.c,v 1.2 2000/11/08 03:50:29 idiscovery Exp $	*/
+/*	$Id: tixDiStyle.c,v 1.2.2.1 2002/01/24 08:59:32 idiscovery Exp $	*/
 
 /*
  * tixDiStyle.c --
@@ -395,7 +396,7 @@ DeleteStyle(stylePtr)
     Tix_DItemStyle * stylePtr;
 {
     Tcl_HashEntry * hashPtr;
-    char buff[120];
+    char *buff;
 
     if (!(stylePtr->base.flags & TIX_STYLE_DELETED)) {
 	stylePtr->base.flags |= TIX_STYLE_DELETED;
@@ -405,8 +406,10 @@ DeleteStyle(stylePtr)
 	        Tcl_GetCommandName(stylePtr->base.interp,
 	        stylePtr->base.styleCmd));
 	}
+        buff=(char *)malloc(strlen(stylePtr->base.name) + 64);
 	sprintf (buff, "%x.%s", stylePtr->base.interp, stylePtr->base.name);
 	hashPtr=Tcl_FindHashEntry(&styleTable, buff);
+        free(buff);
 	if (hashPtr != NULL) {
 	    Tcl_DeleteHashEntry(hashPtr);
 	}
@@ -620,14 +623,16 @@ GetDItemStyle(ddPtr, diTypePtr, styleName, isNew_ret)
     Tcl_HashEntry *hashPtr;
     int isNew;
     Tix_DItemStyle * stylePtr;
-    char buff[120];
+    char *buff;
 
     if (tableInited == 0) {
 	InitHashTables();
     }
 
+    buff=(char *)malloc(strlen(styleName) + 64);
     sprintf (buff, "%x.%s", ddPtr->interp, styleName);
     hashPtr = Tcl_CreateHashEntry(&styleTable, buff, &isNew);
+    free(buff);
     if (!isNew) {
 	stylePtr = (Tix_DItemStyle *)Tcl_GetHashValue(hashPtr);
     }
@@ -661,13 +666,16 @@ static Tix_DItemStyle* FindStyle(styleName, interp)
     Tcl_Interp *interp;		/* Current interpreter. */
 {
     Tcl_HashEntry *hashPtr;
-    char buff[120];
+    char *buff;
 
     if (tableInited == 0) {
 	InitHashTables();
     }
+    buff=(char *)malloc(strlen(styleName) + 64);
     sprintf (buff, "%x.%s", interp, styleName);
-    if ((hashPtr=Tcl_FindHashEntry(&styleTable, buff)) == NULL) {
+    hashPtr=Tcl_FindHashEntry(&styleTable, buff);
+    free(buff);
+    if (hashPtr == NULL) {
 	return NULL;
     }
 
@@ -960,3 +968,4 @@ static char *DItemStylePrintProc(clientData, tkwin, widRec,offset, freeProcPtr)
 	return 0;
     }
 }
+
