@@ -1,5 +1,5 @@
 
-/*	$Id: tixImgCmp.c,v 1.3 2000/10/17 16:41:56 idiscovery Exp $	*/
+/*	$Id: tixImgCmp.c,v 1.3.2.1 2002/12/15 04:21:53 idiscovery Exp $	*/
 
 /* 
  * tkImgCmp.c --
@@ -168,12 +168,14 @@ static void		ImgCmpFreeResources _ANSI_ARGS_((ClientData clientData));
 
 Tk_ImageType tixCompoundImageType = {
     "compound",			/* name */
-    ImgCmpCreate,		/* createProc */
+    (Tk_ImageCreateProc *) ImgCmpCreate,		/* createProc */
     ImgCmpGet,			/* getProc */
     ImgCmpDisplay,		/* displayProc */
     ImgCmpFree,			/* freeProc */
     ImgCmpDelete,		/* deleteProc */
-    (Tk_ImageType *) NULL	/* nextPtr */
+    (Tk_ImagePostscriptProc *) NULL, /* postscriptProc */
+    (Tk_ImageType *) NULL,	/* nextPtr */
+    (char *) NULL, 		/* reserved */
 };
 
 static Tk_ConfigSpec configSpecs[] = {
