@@ -1,6 +1,6 @@
 # -*- mode: TCL; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
 #
-#	$Id: Grid.tcl,v 1.2.2.2 2001/12/09 02:54:02 idiscovery Exp $
+#	$Id: Grid.tcl,v 1.2.2.3 2002/01/24 10:08:58 idiscovery Exp $
 #
 # Grid.tcl --
 #
@@ -14,7 +14,10 @@
 #
 
 
-
+global tkPriv
+if {![llength [info globals tkPriv]]} {
+    tk::unsupported::ExposePrivateVariable tkPriv
+}
 #--------------------------------------------------------------------------
 # tkPriv elements used in this file:
 #
@@ -22,6 +25,13 @@
 # fakeRelease -		Cancel the ButtonRelease-1 after the user double click
 #--------------------------------------------------------------------------
 #
+foreach fun {tkCancelRepeat} {
+    if {![llength [info commands $fun]]} {
+	tk::unsupported::ExposePrivateCommand $fun
+    }
+}
+unset fun
+
 proc tixGridBind {} {
     tixBind TixGrid <ButtonPress-1> {
 	tixGrid:Button-1 %W %x %y
