@@ -1,6 +1,6 @@
 # -*- mode: TCL; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
 #
-#	$Id: HList.tcl,v 1.2.2.1 2001/11/03 07:44:03 idiscovery Exp $
+#	$Id: HList.tcl,v 1.2.2.3 2002/07/13 00:47:00 idiscovery Exp $
 #
 # HList.tcl --
 #
@@ -14,8 +14,10 @@
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 #
 
-
-
+global tkPriv
+if {![llength [info globals tkPriv]]} {
+    tk::unsupported::ExposePrivateVariable tkPriv
+}
 #--------------------------------------------------------------------------
 # tkPriv elements used in this file:
 #
@@ -23,6 +25,13 @@
 # fakeRelease -		Cancel the ButtonRelease-1 after the user double click
 #--------------------------------------------------------------------------
 #
+foreach fun {tkCancelRepeat} {
+    if {![llength [info commands $fun]]} {
+	tk::unsupported::ExposePrivateCommand $fun
+    }
+}
+unset fun
+
 proc tixHListBind {} {
     tixBind TixHList <ButtonPress-1> {
 	tixHList:Button-1 %W %x %y ""
@@ -98,8 +107,10 @@ proc tixHListBind {} {
 	set w %W
 	$w yview moveto 0; # $w xview moveto 0
 	set sel [lindex [$w info children] 0]
-	# should be first not disabled
-	$w anchor set $sel
+	if {$sel != ""} {
+	    # should be first not disabled
+	    $w anchor set $sel
+	}
 	tixHList:Keyboard-Browse $w
     }
     tixBind TixHList <End>  {
@@ -107,33 +118,39 @@ proc tixHListBind {} {
 	$w yview moveto 1; #	$w xview moveto 0
 	$w select clear
 	# should be last not disabled
-	set sel [lindex [$w info children .] end]
-	while {[set next [$w info next $sel]] != "" && \
-		![$w info hidden $next] && \
-		[llength [set kids [$w info child $sel]]]} {
-	    set sel [lindex $kids end]
+	set sel [lindex [$w info children] end]
+	if {$sel != ""} {
+	    while {[set next [$w info next $sel]] != "" && \
+		       ![$w info hidden $next] && \
+		       [llength [set kids [$w info child $sel]]]} {
+		set sel [lindex $kids end]
+	    }
+	    $w anchor set $sel
 	}
-	$w anchor set $sel
 	tixHList:Keyboard-Browse $w
     }
     tixBind TixHList <Control-Home> {
 	set w %W
 	$w yview moveto 0; # $w xview moveto 0
 	set sel [lindex [$w info children] 0]
-	# should be first not disabled
-	$w anchor set $sel
+	if {$sel != ""} {
+	    # should be first not disabled
+	    $w anchor set $sel
+	}
     }
     tixBind TixHList <Control-End>  {
 	set w %W
 	$w yview moveto 1; #	$w xview moveto 0
 	# should be last not disabled
-	set sel [lindex [$w info children .] end]
-	while {[set next [$w info next $sel]] != "" && \
-		![$w info hidden $next] && \
-		[llength [set kids [$w info child $sel]]]} {
-	    set sel [lindex $kids end]
+	set sel [lindex [$w info children] end]
+	if {$sel != ""} {
+	    while {[set next [$w info next $sel]] != "" && \
+		       ![$w info hidden $next] && \
+		       [llength [set kids [$w info child $sel]]]} {
+		set sel [lindex $kids end]
+	    }
+	    $w anchor set $sel
 	}
-	$w anchor set $sel
     }
     #
     # Don't use tixBind because %A causes Tk 8.3.2 to crash
