@@ -1,6 +1,6 @@
 # -*- mode: TCL; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
 #
-#	$Id: TList.tcl,v 1.2.2.2 2001/12/09 02:54:02 idiscovery Exp $
+#	$Id: TList.tcl,v 1.2.2.3 2002/01/24 10:08:58 idiscovery Exp $
 #
 # TList.tcl --
 #
@@ -14,7 +14,10 @@
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 #
 
-
+global tkPriv
+if {![llength [info globals tkPriv]]} {
+    tk::unsupported::ExposePrivateVariable tkPriv
+}
 
 #--------------------------------------------------------------------------
 # tkPriv elements used in this file:
