@@ -1,11 +1,11 @@
 # -*-mode: tcl; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
 #
 #
-#	$Id: WmDefault.tcl,v 1.1.2.8 2001/12/09 02:52:40 idiscovery Exp $
+#	$Id: WmDefault.tcl,v 1.1.2.10 2002/12/02 04:02:51 idiscovery Exp $
 #
 #	Description: Package for making Tk apps use the CDE/KDE/Gnome/Windows scheme
 #	Prefix: wm_default::
-#	Url: http://tix.sourceforge.net/Tide/
+#	Url: http://tix.sourceforge.net/Tixapps/
 #
 # Usage:
 #	It should be sufficient at the beginning of a wish app to simply:
@@ -74,6 +74,7 @@ proc tixDetermineWM {} {
 	    } elseif {[string match *KDE_DESKTOP_WINDOW* $xatoms]} {
 		set type kde2
 	    }
+	    # KDE3 is treated as kde2
 	}
 	if {$type != ""} {
 	    # drop through
@@ -118,7 +119,7 @@ namespace eval ::wm_default {
                 *Scale *Radiobutton *Checkbutton
     }
     if {$_usetix} {lappend _system_font_widgets \
-	   *TixBalloon*Label *TixLabelFrame*Label \
+	   *TixBalloon*message *TixLabelFrame*Label \
 	   *TixControl*label *TixControl*Label \
 	   *TixLabelEntry*label *TixNoteBook.nbframe \
 	   *TixFileEntry*label *TixComboBox*label  \
@@ -213,6 +214,7 @@ namespace eval ::wm_default {
     set _bd 2
     # Pick a default font size in pixels
     set _screenheight [winfo screenheight .]
+    # Does anyone know what these should be for Unix and Windows?
     if {$_screenheight < 500} {
 	# for 640x480
 	set _pixel 10
@@ -224,22 +226,22 @@ namespace eval ::wm_default {
 	set _pixel 12
 	set _point 8
     } elseif {$_screenheight < 800} {
+	# for 1024x768
+	set _pixel 11
+	set _point 8
+    } elseif {$_screenheight < 1300} {
 	# for 1024x768
 	set _pixel 12
 	set _point 8
-    } elseif {$_screenheight < 1100} {
-	# for 1200x1000
+    } else {
 	set _pixel 14
 	set _point 10
-    } else {
-	set _pixel 18
-	set _point 12
     }
 
     # setup defaults depending on the OS and Window Manager
     # Really should do another version for mono
     switch -exact -- $tcl_platform(platform) windows {
-
+	# unfortunately CYGWIN is treated as windows
 	if {$tcl_platform(osVersion) < 5} {
 	    set _prop_default "MS Sans Serif"
 	} else {
@@ -377,7 +379,7 @@ namespace eval ::wm_default {
 		menubackground       	$_bg \
 		menuforeground       	Black
 
-	variable highlightthickness         	2
+	variable highlightthickness         	1
 
 	# Windows does not have an activebackground, but Tk does
 	variable activebackground "#ececec"
@@ -479,10 +481,10 @@ namespace eval ::wm_default {
 	set font [lindex $list 2]
 	set font [string tolow $font]
 	if {$font != "" && [lsearch -exact [font families] $font] > -1} {
-	    set wm_default::textfamily $font
+	    set ::wm_default::textfamily $font
 	    debug "Setting textfamily to $font"
-	    set wm_default::systemfamily $font
-	    set wm_default::menufamily $font
+	    set ::wm_default::systemfamily $font
+	    set ::wm_default::menufamily $font
 	} else {
 	    debug "Unable to set font: '$list'"
 	}
@@ -490,12 +492,12 @@ namespace eval ::wm_default {
 	if {[set size [lindex $list 7]] != "" && \
 		[string is int $size]} {
 	    debug "Setting fontsize to '$size'"
-	    set wm_default::fontsize $size
+	    set ::wm_default::fontsize $size
 	} elseif {[set size [lindex $list 8]] != "" && \
 		[string is int $size]} {
 	    if {$size > 100} {set size [expr $size / 10]}
 	    debug "Setting fontsize to '$size'"
-	    set wm_default::fontsize $size
+	    set ::wm_default::fontsize $size
 	} else {
 	    debug "Unable to set fontsize: '$list'"
 	}
@@ -518,17 +520,17 @@ namespace eval ::wm_default {
 		    foo font]} {
 		set list [split $font ","]
 		set font [lindex $list 0]
-		set wm_default::fixedfamily $font
+		set ::wm_default::fixedfamily $font
 		debug "Setting fixedfamily to $font"
 	    }
 	    if {[regexp -- "\nfont=(\[-a-zA-Z0-9,\]+)" $contents \
 		    foo font]} {
 		set list [split $font ","]
 		set font [lindex $list 0]
-		set wm_default::textfamily $font
+		set ::wm_default::textfamily $font
 		debug "Setting textfamily to $font"
-		set wm_default::systemfamily $font
-		set wm_default::menufamily $font
+		set ::wm_default::systemfamily $font
+		set ::wm_default::menufamily $font
 	    }
 	}
 
@@ -559,7 +561,7 @@ namespace eval ::wm_default {
 	debug "Setting up KDE environment"
 
 	# Look for system the user settings
-	set dirs ~/.kde
+	set dirs [list ~/.kde ~/.kde2]
 	if {[info exists env(KDEDIR)] && [file isdir $env(KDEDIR)]} {
 	    lappend dirs $env(KDEDIR)
 	}
@@ -578,57 +580,57 @@ namespace eval ::wm_default {
 		if {[regexp -- "\nselectBackground=(\[0-9,\]+)" $contents \
 			foo color]} {
 		    set color [eval format "#%02x%02x%02x" [split $color ","]]
-		    set wm_default::selectbackground $color
+		    set ::wm_default::selectbackground $color
 		    debug "setting selectbackground to $color"
 		}
 		if {[regexp -- "\nselectForeground=(\[0-9,\]+)" $contents \
 			foo color]} {
 		    set color [eval format "#%02x%02x%02x" [split $color ","]]
-		    set wm_default::selectforeground $color
+		    set ::wm_default::selectforeground $color
 		    debug "setting selectforeground to $color"
 		}
 		if {[regexp -- "\nforeground=(\[0-9,\]+)" $contents \
 			foo color]} {
 		    set color [eval format "#%02x%02x%02x" [split $color ","]]
-		    set wm_default::foreground $color
+		    set ::wm_default::foreground $color
 		    debug "setting foreground to $color"
 		}
 		if {[regexp -- "\nbackground=(\[0-9,\]+)" $contents \
 			foo color]} {
 		    set color [eval format "#%02x%02x%02x" [split $color ","]]
-		    set wm_default::background $color
+		    set ::wm_default::background $color
 		    debug "setting background to $color"
 		}
 		if {[regexp -- "\nwindowBackground=(\[0-9,\]+)" $contents \
 			foo color]} {
 		    set color [eval format "#%02x%02x%02x" [split $color ","]]
-		    set wm_default::textbackground $color
+		    set ::wm_default::textbackground $color
 		    debug "setting textbackground to $color"
 		}
 		if {[regexp -- "\nvisitedLinkColor=(\[0-9,\]+)" $contents \
 			foo color]} {
 		    set color [eval format "#%02x%02x%02x" [split $color ","]]
-		    set wm_default::vlinkcolor $color
+		    set ::wm_default::vlinkcolor $color
 		    debug "setting vlinkcolor to $color"
 		}
 		if {[regexp -- "\nlinkColor=(\[0-9,\]+)" $contents \
 			foo color]} {
 		    set color [eval format "#%02x%02x%02x" [split $color ","]]
-		    set wm_default::linkcolor $color
+		    set ::wm_default::linkcolor $color
 		    debug "setting linkcolor to $color"
 		}
 		if {[regexp -- "\nactiveFont=(\[-a-zA-Z0-9,\]+)" $contents \
 			foo font]} {
 		    set list [split $font ","]
 		    set font [lindex $list 0]
-		    set wm_default::textfamily $font
+		    set ::wm_default::textfamily $font
 		    set size [lindex $list 1]
-		    if {[string is integer $size]} {
-			set wm_default::fontsize $size
+		    if {$size != "" && [string is integer $size]} {
+			set ::wm_default::fontsize $size
 		    }
 		    debug "Setting textfamily to $font"
-		    set wm_default::systemfamily $font
-		    set wm_default::menufamily $font
+		    set ::wm_default::systemfamily $font
+		    set ::wm_default::menufamily $font
 		}
 	    }
 
@@ -644,13 +646,13 @@ namespace eval ::wm_default {
 		catch {close $fd}
 		if {[regexp -- "\nDesktop1Region=(\[0-9+\]+)" $contents \
 			foo region]} {
-		    set wm_default::geometry $region
+		    set ::wm_default::geometry $region
 		    debug "Setting geometry to $region"
 		}
 
 		if {[regexp -- "\nFocusPolicy=ClickToFocus" $contents \
 			foo region]} {
-		    set wm_default::focusmodel clicktofocus
+		    set ::wm_default::focusmodel clicktofocus
 		    debug "Setting focusmodel to clicktofocus"
 		} else {
 		    # followsmouse
@@ -742,16 +744,16 @@ namespace eval ::wm_default {
 		    }
 		}
 	    }
-	    set wm_default::background $bg
-	    set wm_default::foreground $fg
-	    set wm_default::textfamily $txtFont
-	    set wm_default::systemfamily $sysFont
-	    set wm_default::menufamily $sysFont
-	    set wm_default::textbackground $txtBg
-	    set wm_default::textforeground $txtFg
-	    set wm_default::selectbackground $selBg
-	    set wm_default::selectforeground $selFg
-	    set wm_default::selectcolor $selCol
+	    set ::wm_default::background $bg
+	    set ::wm_default::foreground $fg
+	    set ::wm_default::textfamily $txtFont
+	    set ::wm_default::systemfamily $sysFont
+	    set ::wm_default::menufamily $sysFont
+	    set ::wm_default::textbackground $txtBg
+	    set ::wm_default::textforeground $txtFg
+	    set ::wm_default::selectbackground $selBg
+	    set ::wm_default::selectforeground $selFg
+	    set ::wm_default::selectcolor $selCol
 	}
     }
 
@@ -764,28 +766,42 @@ namespace eval ::wm_default {
 	variable fixed_font 
 	variable text_font 
 
+	# This should be a variable
+	set size $::wm_default::fontsize
+
         #
         # Set default fonts 
         #
 
 	global tcl_platform env
 	switch -exact -- $tcl_platform(platform) windows {
-	    set system_font [list $::wm_default::systemfamily $::wm_default::fontsize]
-	    set menu_font [list $::wm_default::menufamily $::wm_default::fontsize]
-	    set text_font [list $::wm_default::textfamily $::wm_default::fontsize]
-	    set fixed_font [list $::wm_default::fixedfamily $::wm_default::fontsize]
+	    
+	    if {$size == "" || ![string is integer $size]} {
+		debug "Internal error - fontsize not set"
+		set size 8 ; # pixel
+	    }
+
+	    set system_font [list $::wm_default::systemfamily $size]
+	    set menu_font [list $::wm_default::menufamily $size]
+	    set text_font [list $::wm_default::textfamily $size]
+	    set fixed_font [list $::wm_default::fixedfamily $size]
 	} default {
-	    set system_font [list $::wm_default::systemfamily -$::wm_default::fontsize]
+	    if {$size == "" || ![string is integer $size]} {
+		puts stderr "Internal error - fontsize not set"
+		set size 10 ; # pixel
+	    }
+
+	    set system_font [list $::wm_default::systemfamily -$size]
 	    if {[set type $::wm_default::wm] == ""} {
 		# Generic unix
 		# some Unix Wms seem to make Menu fonts bold - ugly IMHO
-		set menu_font [list $::wm_default::menufamily -$::wm_default::fontsize bold]
+		set menu_font [list $::wm_default::menufamily -$size bold]
 	    } else {
 		# gnome kde1 kde2 cde kde don't
-		set menu_font [list $::wm_default::menufamily -$::wm_default::fontsize]
+		set menu_font [list $::wm_default::menufamily -$size]
 	    }
-	    set text_font [list $::wm_default::textfamily -$::wm_default::fontsize]
-	    set fixed_font [list $::wm_default::fixedfamily -$::wm_default::fontsize]
+	    set text_font [list $::wm_default::textfamily -$size]
+	    set fixed_font [list $::wm_default::fixedfamily -$size]
 	}
     }
 
@@ -910,6 +926,7 @@ namespace eval ::wm_default {
             option add $pref.background $::wm_default::background $pri
             option add $pref.foreground $::wm_default::foreground $pri
             option add $pref.disabledForeground $::wm_default::disabledforeground $pri
+            option add $pref.highlightThickness $::wm_default::highlightthickness $pri
         }
 
 	switch -exact -- $tcl_platform(platform) windows {
@@ -922,6 +939,8 @@ namespace eval ::wm_default {
 	option add *Menu.selectColor $_menu_select_color $pri
 	if {$_usetix} {
 	    option add *TixMenu.selectColor $_menu_select_color $pri
+            option add *TixBalloon*message.background $::wm_default::textbackground $pri
+	    
 	}
 
 	# Windows does not have an activebackground, but Tk does
