@@ -1,9 +1,10 @@
+# -*-mode: tcl; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
 
-set tix_version 8.1.3
+set tix_version 8.1.4 
 
 package require Tcl 8.1
 
-# $Id: tix-man2html.tcl,v 1.3.2.4 2001/12/09 04:12:20 idiscovery Exp $
+# $Id: tix-man2html.tcl,v 1.3.2.8 2002/12/11 07:16:39 idiscovery Exp $
 #
 # Convert Ousterhout format man pages into highly crosslinked
 # hypertext.
@@ -82,9 +83,9 @@ proc parse_command_line {} {
     set webdir ../man/html
 
     # Directory names for Tcl, Tk and Tix, in priority order.
-    set tclDirList {tcl8.3.3 tcl8.3.2 tcl8.2.3 tcl8.3 tcl8.2 tcl8.1 tcl8.0 tcl}
-    set tkDirList {tk8.3.3 tk8.3.2 tk8.2.3 tk8.3 tk8.2 tk8.1 tk8.0 tk}
-    set tixDirList {tix-8.1.2 tix-8.1.3 tix}
+    set tclDirList {tcl8.4.1 tcl8.4.0 tcl8.3.5 tcl8.3.4 tcl8.3.3 tcl8.3.2 tcl8.2.3 tcl8.3 tcl8.2 tcl8.1 tcl8.0 tcl}
+    set tkDirList {tk8.4.1 tk8.4.0 tcl8.3.5 tk8.3.4 tk8.3.3 tk8.3.2 tk8.2.3 tk8.3 tk8.2 tk8.1 tk8.0 tk}
+    set tixDirList {tix-8.1.4 tix-8.1.3 tix-8.1.2 tix}
 
     # Handle arguments a la GNU:
     #   --version
